<?php
/**
 * Best Charity functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Best_Charity
 */

if ( ! function_exists( 'best_charity_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function best_charity_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Best Charity, use a find and replace
		 * to change 'best-charity' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'best-charity', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		add_image_size( 'recent-post-of-footer', 70, 70, true );
		add_image_size( 'page-thumb', 823, 397.141, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'best-charity' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'best_charity_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add theme support for Gutenberg compatible
		add_theme_support( 'align-wide' );
		add_theme_support( 'editor-styles' );
		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'responsive-embeds' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'best_charity_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function best_charity_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'best_charity_content_width', 640 );
}
add_action( 'after_setup_theme', 'best_charity_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function best_charity_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'best-charity' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'best-charity' ),
		'before_widget' => '<div id="%1$s" class="mgb-md widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="s-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer widget', 'best-charity' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'best-charity' ),
		'before_widget' => '<div id="%1$s" class="col-xl-3 col-sm-6 widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="f-title">',
		'after_title'   => '</h2>',
	) );

}
add_action( 'widgets_init', 'best_charity_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
require get_template_directory(). '/inc/enqueue.php';


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';


/**
 * Bootstrap Navwalker
 */
require get_template_directory() . '/inc/wp-bootstrap-navwalker.php';

/*
* Breadcrumbs Trails
*/
require_once get_template_directory() . '/inc/breadcrumbs.php';


/*Bootstrap Pagination Function*/

function best_charity_portfolio_bs_pagination($pages = '', $range = 4)
{  
	$showitems = ($range * 2) + 1;  
	$paged = get_query_var( 'paged');

	if(empty($paged)) $paged = 1;
	if($pages == '')
	{
		global $wp_query; 
		$pages = $wp_query->max_num_pages;
		if(!$pages)
		{
			$pages = 1;
		}
	}   

	if(1 != $pages)
	{
		echo '<ul class="pagination">';
		for ($i=1; $i <= $pages; $i++)
		{
			if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
			{
				echo ($paged == $i)? "<li class=\"page-item active\"><a href='".esc_url(get_pagenum_link($i))."' class='page-link'>".esc_html($i)."</a></li>":"<li class='page-item'><a href='".esc_url(get_pagenum_link($i))."' class='page-link'>".esc_html($i)."</a></li>";
			}
		}
		echo '</ul>';
	}
}

add_filter( 'post_thumbnail_html', 'remove_thumbnail_dimensions', 10, 3 );

function remove_thumbnail_dimensions( $html, $post_id, $post_image_id ) {
    $html = preg_replace( '/(width|height)=\"\d*\"\s/', "", $html );
    return $html;
}

// Social Sharing Function
function best_charity_social_sharing_buttons() {
	$content = '';
	global $post;
	if(is_singular() || is_home()){

		// Get current page URL 
		$bestNewsURL = urlencode(get_permalink());

		// Get current page title
		$bestNewsTitle = htmlspecialchars(urlencode(html_entity_decode(get_the_title(), ENT_COMPAT, 'UTF-8')), ENT_COMPAT, 'UTF-8');
		// $bestNewsTitle = str_replace( ' ', '%20', get_the_title());
		
		// Get Post Thumbnail for pinterest
		$bestNewsThumbnail = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );

		// Construct sharing URL without using any script
		$twitterURL = 'https://twitter.com/intent/tweet?text='.$bestNewsTitle.'&amp;url='.$bestNewsURL.'&amp;via=PawanDongol';
		$facebookURL = 'https://www.facebook.com/sharer/sharer.php?u='.$bestNewsURL;
		$linkedInURL = 'https://www.linkedin.com/shareArticle?mini=true&url='.$bestNewsURL.'&amp;title='.$bestNewsTitle;
		// Based on popular demand added Pinterest too
		$pinterestURL = 'https://pinterest.com/pin/create/button/?url='.$bestNewsURL.'&amp;media='.$bestNewsThumbnail[0].'&amp;description='.$bestNewsTitle;

		// Add sharing button at the end of page/page content
		$content .= '<ul class="slinks">';
		$content .='<li><a href="'. esc_url( $facebookURL ) .'" target="_blank"><span class="fa fa-facebook"></span></a></li>';
		$content .='<li><a href="'. esc_url( $twitterURL ) .'" target="_blank"><span class="fa fa-twitter"></span></a></li>';
		$content .='<li><a href="'. esc_url( $pinterestURL ).'" target="_blank"><span class="fa fa-pinterest"></span></a></li>';
		$content .='<li><a href="'. esc_url( $linkedInURL ).'" target="_blank"><span class="fa fa-linkedin"></span></a></li>';
		$content .= '</ul>';
		
		return $content;
	}else{
		// if not a post/page then don't include sharing button
		return $content;
	}
}

/*
* Related Post
*/
function best_charity_get_related_posts( $taxonomy = '', $args = array() )
{ 
	if ( !is_single() )
		return false;

	if ( !$taxonomy ) 
		return false;

	$taxonomy = filter_var( $taxonomy, FILTER_SANITIZE_STRING );
	if ( !taxonomy_exists( $taxonomy ) )
		return false;

	$current_post = get_queried_object();

	$terms = wp_get_post_terms( $current_post->ID, $taxonomy, array( 'fields' => 'ids') );

	if ( !$terms || is_wp_error( $terms ) )
		return false;

	$defaults = array(
		'post_type' => $current_post->post_type,
		'post__not_in' => array( $current_post->ID),
		'tax_query' => array(
			array(
				'taxonomy' => $taxonomy,
				'terms' => $terms,
				'include_children' => false
			),
		),
	);

	if ( is_array( $args ) ) {
		$args = wp_parse_args( $args, $defaults );
	} else {
		$args = $defaults;
	}

	$q = get_posts( $args );

	return $q;
}
/*
* Custom widgets
*/
require_once get_template_directory() . '/inc/widgets/widget.php';


/**
 * Elementor hello world.
 */
require get_template_directory() . '/elementor-widget/widgets.php';


if ( is_admin() ) {
	// Load about.
	
	require_once trailingslashit( get_template_directory() ) . 'inc/theme-info/class-about.php';
	require_once trailingslashit( get_template_directory() ) . 'inc/theme-info/about.php';

	// Load demo.
	require_once trailingslashit( get_template_directory() ) . 'inc/demo/class-demo.php';
	require_once trailingslashit( get_template_directory() ) . 'inc/demo/demo.php';
}

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

